==> zio-aws-globalaccelerator_2.13-5.17.157.2-sources.jar: zio/aws/globalaccelerator/model/CreateListenerResponse.scala <==
package zio.aws.globalaccelerator.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class CreateListenerResponse(
    listener: Option[zio.aws.globalaccelerator.model.Listener] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.globalaccelerator.model.CreateListenerResponse = {
    import CreateListenerResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.globalaccelerator.model.CreateListenerResponse
      .builder()
      .optionallyWith(listener.map(value => value.buildAwsValue()))(_.listener)
      .build()
  }
  def asReadOnly
      : zio.aws.globalaccelerator.model.CreateListenerResponse.ReadOnly =
    zio.aws.globalaccelerator.model.CreateListenerResponse.wrap(buildAwsValue())
}
object CreateListenerResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.globalaccelerator.model.CreateListenerResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.globalaccelerator.model.CreateListenerResponse =
      zio.aws.globalaccelerator.model
        .CreateListenerResponse(listener.map(value => value.asEditable))
    def listener: Option[zio.aws.globalaccelerator.model.Listener.ReadOnly]
    def getListener: ZIO[
      Any,
      AwsError,
      zio.aws.globalaccelerator.model.Listener.ReadOnly
    ] = AwsError.unwrapOptionField("listener", listener)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.globalaccelerator.model.CreateListenerResponse
  ) extends zio.aws.globalaccelerator.model.CreateListenerResponse.ReadOnly {
    override val listener
        : Option[zio.aws.globalaccelerator.model.Listener.ReadOnly] = scala
      .Option(impl.listener())
      .map(value => zio.aws.globalaccelerator.model.Listener.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.globalaccelerator.model.CreateListenerResponse
  ): zio.aws.globalaccelerator.model.CreateListenerResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-globalaccelerator_2.13-6.20.78.3-sources.jar: zio/aws/globalaccelerator/model/CreateListenerResponse.scala <==
package zio.aws.globalaccelerator.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class CreateListenerResponse(
    listener: Optional[zio.aws.globalaccelerator.model.Listener] =
      Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.globalaccelerator.model.CreateListenerResponse = {
    import CreateListenerResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.globalaccelerator.model.CreateListenerResponse
      .builder()
      .optionallyWith(listener.map(value => value.buildAwsValue()))(_.listener)
      .build()
  }
  def asReadOnly
      : zio.aws.globalaccelerator.model.CreateListenerResponse.ReadOnly =
    zio.aws.globalaccelerator.model.CreateListenerResponse.wrap(buildAwsValue())
}
object CreateListenerResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.globalaccelerator.model.CreateListenerResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.globalaccelerator.model.CreateListenerResponse =
      zio.aws.globalaccelerator.model
        .CreateListenerResponse(listener.map(value => value.asEditable))
    def listener: Optional[zio.aws.globalaccelerator.model.Listener.ReadOnly]
    def getListener: ZIO[
      Any,
      AwsError,
      zio.aws.globalaccelerator.model.Listener.ReadOnly
    ] = AwsError.unwrapOptionField("listener", listener)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.globalaccelerator.model.CreateListenerResponse
  ) extends zio.aws.globalaccelerator.model.CreateListenerResponse.ReadOnly {
    override val listener
        : Optional[zio.aws.globalaccelerator.model.Listener.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.listener())
        .map(value => zio.aws.globalaccelerator.model.Listener.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.globalaccelerator.model.CreateListenerResponse
  ): zio.aws.globalaccelerator.model.CreateListenerResponse.ReadOnly =
    new Wrapper(impl)
}
